@@ -9,9 +9,11 @@ PixelArray 第三方微服务客户端
 - cron: 定时任务管理模块
 - user: 用户管理模块
 - unified_login: 统一登录模块
+- feedback: 客户反馈模块
+- project: 项目管理模块
 """
 
-__version__ = "1.1.2"
+__version__ = "1.2.0"
 __author__ = "Lu qi"
 __email__ = "qi.lu@pixelarrayai.com"
 
@@ -21,4 +23,6 @@ __all__ = [
     "cron",
     "user",
     "order",
+    "feedback",
+    "project",
 ]
